caellion-python-commons: caellion.pycommons.stringutil.unixpassword.EmptyFieldNameException Class Reference

caellion-python-commons

caellion.pycommons.stringutil.unixpassword.EmptyFieldNameException Class Reference

This exception is raised when an empty field name is encountered. More...

Inheritance diagram for caellion.pycommons.stringutil.unixpassword.EmptyFieldNameException:

## Detailed Description

This exception is raised when an empty field name is encountered.

Definition at line 14 of file unixpassword.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/stringutil/unixpassword.py